#!/bin/sh

if [ $# -ne 2 ]; then
    echo "Missing parameters"
    exit 1
fi

NAME=$1
SRC_FOLDER=$2
USER=tkl
HOST=probook

# Setting this, so the repo does not need to be given on the commandline:
export BORG_REPO=ssh://$USER@$HOST/backup
# some helpers and error handling:
info() { printf "\n%s %s\n\n" "$( date )" "$*" >&2; }
trap 'echo $( date ) Backup interrupted >&2; exit 2' INT TERM

info "Starting backup"

# Backup the most important directories into an archive named after
# the machine this script is currently running on:

borg create                         \
    --verbose                       \
    --filter AME                    \
    --list                          \
    --stats                         \
    --show-rc                       \
    --compression lzma,9            \
    --exclude-caches                \
    --exclude 'sh:**/.git'          \
                                    \
    ::$NAME'-{now}'                 \
    $SRC_FOLDER

backup_exit=$?

info "Pruning repository"

borg prune                          \
    --list                          \
    --glob-archives $NAME'-*'       \
    --show-rc                       \
    --keep-within   1w

prune_exit=$?

# actually free repo disk space by compacting segments

info "Compacting repository"

borg compact

compact_exit=$?

# use highest exit code as global exit code
global_exit=$(( backup_exit > prune_exit ? backup_exit : prune_exit ))
global_exit=$(( compact_exit > global_exit ? compact_exit : global_exit ))

if [ ${global_exit} -eq 0 ]; then
    info "Backup, Prune, and Compact finished successfully"
elif [ ${global_exit} -eq 1 ]; then
    info "Backup, Prune, and/or Compact finished with warnings"
else
    info "Backup, Prune, and/or Compact finished with errors"
fi

exit ${global_exit}
